import mx.controls.DataGrid;
/**
 * Defines common component and text field styles for the Stock Watcher application.
 * All vars and functions are static so this does not need to be instantiated.
 */
 class StockStyles {
	
	public static var kStyleName:String = "StockWatcher";
	public static var kGridStyleName:String = "StockWatcherGrid";
	
	/**
	 * Defines a global, custom style for this application
	 */
	 public static function defineStyles() {
		
		if (_global.styles[kStyleName] == undefined) {
 			 _global.styles[kStyleName] = new mx.styles.CSSStyleDeclaration();
			 
			_global.styles[kStyleName].setStyle("color", 0x000066);
			_global.styles[kStyleName].setStyle("fontSize", 10);
			_global.styles[kStyleName].setStyle("fontFamily", "Verdana");
			//_global.styles[kStyleName].setStyle("themeColor", "haloGreen");
			_global.styles[kStyleName].setStyle("rollOverColor",0xDDFFDD);
			_global.styles[kStyleName].setStyle("selectionColor",0xDDFFDD);
			_global.styles[kStyleName].setStyle("textRollOverColor",0x000000);
			_global.styles[kStyleName].setStyle("textSelectedColor",0x000000);
		}		
		
		// duplicate the standard style for the grid
		if (_global.styles[kGridStyleName] == undefined) {
 			_global.styles[kGridStyleName] = _global.styles[kStyleName];
			_global.styles[kGridStyleName].setStyle("alternatingRowColors ", [ 0xDDFFDD, 0xFFFFFF ]);
		}		
	}
	
	/**
	 * Sets instance-specific styles for a DataGrid
	 */
	public static function setGridStyles(oGrid:DataGrid) {
		oGrid.setStyle("alternatingRowColors ", [ 0xDDFFDD, 0xFFFFFF ]);
		oGrid.setStyle("color", 0x000066);
		oGrid.setStyle("fontSize", 10);
		oGrid.setStyle("fontFamily", "Verdana");
		//oGrid.setStyle("themeColor", "haloGreen");
		oGrid.setStyle("rollOverColor",0xDDFFDD);
		oGrid.setStyle("selectionColor",0xDDFFDD);
		oGrid.setStyle("textRollOverColor",0x000000);
		oGrid.setStyle("textSelectedColor",0x000000);
	}
	
	/**
	 * Returns a standard TextFormat for this application
	 */
	public static function getTextFormat():TextFormat {
		var oTextFormat:TextFormat = new TextFormat();
		oTextFormat = new TextFormat();
		oTextFormat.color = 0x000066;
		oTextFormat.font = "Verdana";
		oTextFormat.size = 11;
		
		return oTextFormat;
	}

	/**
	 * This convenience method applies styles to every object contained in the MovieClip
	 * passed in. 
	 */
	public static function stylizeAll(mc:MovieClip) {
		StockUtils.trace("stylizeAll()", "StockStyles");
		var tf:TextFormat = getTextFormat();
		for (var i in mc) {
			StockUtils.trace(i);
			var uiObj = mc[i];
			
			if (uiObj instanceof TextField) 
			{
				// If the contained object is a TextField, it gets a TextFormat
				TextField(uiObj).setTextFormat(tf);
				TextField(uiObj).setNewTextFormat(tf);
			} 
			else if (uiObj instanceof mx.core.UIObject) 
			{
				// If the contained object is a UIObject, it gets the global custom style
				uiObj.setStyle("styleName", kStyleName);
			}
		}
	}
		
		
	
}